# brainage

## get_brainage.sh

This script is used for brain age prediction. Below is a description of each input arguments:

### Usage

```
./get_brainage.sh -input <input_directory> \
                  -output <output_directory> \
                  -BIDS <yes/no> \
                  -CONDOR <yes/no> \
                  -RAW <yes/no> \
                  -RUN_FILE <bash_file_path> \
                  -SAVE_ALL <yes/no> \
                  -CONTAINER_PATH <path/to/containers> \
```

* input: input directory (can be a folder containing raw or preprocessed T1 MR Image which can be .nii, .nii.gz or .mgz)
* output: output directory where the results will be stored in `<subject_name>_<model>.csv` 
* BIDS: are the input files stored in BIDS format ?
* CONDOR: provides a `condor.submit` file
* RAW: are the input files raw ?
* RUN_FILE: path to the `run_<model>.sh` file
* SAVE_ALL: Do you want to save the intermidiate files (for ex: `subject_features`), if yes then the files will be stored in the folder `<subject_name>_<model>`
* CONTAINER_PATH: path to the directory containing the container images

### 'brainageR' folder:

1) Building the container

`singularity build brainageR.sif brainageR.def` (**not working at the moment**)

2) Run the `get_brainage.sh` with the proper files and paths

Example:

```
./get_brainage.sh -input <input_directory> \
                  -output <output_directory> \
                  -BIDS <yes/no> \
                  -CONDOR <yes/no> \
                  -RAW <yes/no> \
                  -RUN_FILE run_brainageR.sh \
                  -SAVE_ALL <yes/no> \
                  -CONTAINER_PATH <path/to/containers> \
```

### 'Enigma' folder:

1) Building the containers

Preprocessing: `singularity build --fakeroot cat_preprocessing.simg Singularity_r2042` 

Prediction: `singularity build --fakeroot enigma_stacking_agepred.simg enigma_stacking_pred.def`

/!\ It is important to not change the name of the containers

2) Run the `get_brainage.sh` with the proper files and paths

Example:

```
./get_brainage.sh -input <input_directory> \
                  -output <output_directory> \
                  -BIDS <yes/no> \
                  -CONDOR <yes/no> \
                  -RAW <yes/no> \
                  -RUN_FILE run_enigma.sh \
                  -SAVE_ALL <yes/no> \
                  -CONTAINER_PATH <path/to/containers> \
```

### 'More' folder:

1) Downloading the files

You should first download the following files: `Singularity_r2042`, `BA_predict.recipe` and `run_more.sh`

2) Building the containers

Preprocessing: `singularity build --fakeroot cat_preprocessing.simg Singularity_r2042` 

Prediction: `singularity build --fakeroot BA_predict.sif BA_predict.recipe `

/!\ It is important to not change the name of the containers

3) Run the appropriate bash script for one subject or several

Examples: 

**For one subject**:

```
./run_more.sh -input <path/to/input_file> \
              -output <path/to/output_dir> \
              -RAW <yes/no> \
              -SAVE_FILE <yes/no> \
              -CONTAINER_PATH <path/to/container_dir> \
              -MODEL_NAME <model_name>
```

* input: path to a single T1 weighted MRI file (nii, nii.gz or mgz)
* output: path to the output directory
* raw: is the input file raw or preprocessed ? (default: yes)
* save_file: Do you want to save intermidiate files ? (default: no)
* container_path: path where the container(s) should be stored 
* Model_name: name of the trained model that you want to use (default: 4sites.S4_R4_pca.gauss.models)


**For several subjects**:


```
./get_brainage.sh -input <input_directory> \
                  -output <output_directory> \
                  -BIDS <yes/no> \
                  -CONDOR <yes/no> \
                  -RAW <yes/no> \
                  -RUN_FILE run_more.sh \
                  -SAVE_ALL <yes/no> \
                  -CONTAINER_PATH <path/to/containers> \
                  -MODEL_NAME <model_name>
```


